<!--
SPDX-FileCopyrightText: 2021 Stephen Ruiz Ltd
SPDX-FileCopyrightText: 2022 Calvin Walton

SPDX-License-Identifier: MIT
-->

# Perfect Freehand Python _(perfect-freehand-python)_

![banner](docs/_static/perfect-freehand-logo.svg)

Draw perfect pressure-sensitive freehand lines. (Python port)

This is a Python port of the 
[perfect-freehand library](https://github.com/steveruizok/perfect-freehand)
originally written by Steve Ruiz in TypeScript. Please reference the
documentation for that library for additional usage examples, links to
other implementations, and to support the original author.

When published to PyPi, the package name is "perfect-freehand" (since the "python" is redundant).
The library name when importing into python code is `perfect_freehand`.

* Documentation: https://docs.bigbluebutton.org/perfect-freehand-python/

## License

This library's code and documentation is released under the terms of the [MIT](LICENSES/MIT.txt) license.
Certain build system files are under the terms of the [CC0-1.0](LICENSES/CC0-1.0.txt) license.
